# Connector

A connector describes the relative motions between two points. A connector also describes the behavior associated with the relative motion.

## Create connectors

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorSection.ConnectorSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Other Classes

```{eval-rst}

.. toggle::

    .. autoclass:: abaqus.Connector.CDCTerm.CDCTerm
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.CDCTermArray.CDCTermArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorBehaviorOption.ConnectorBehaviorOption
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorBehaviorOptionArray.ConnectorBehaviorOptionArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorDamage.ConnectorDamage
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorDamping.ConnectorDamping
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorElasticity.ConnectorElasticity
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorFailure.ConnectorFailure
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorFriction.ConnectorFriction
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorLock.ConnectorLock
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorOptions.ConnectorOptions
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorPlasticity.ConnectorPlasticity
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorPotential.ConnectorPotential
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorPotentialArray.ConnectorPotentialArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorStop.ConnectorStop
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.DerivedComponent.DerivedComponent
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.TangentialBehavior.TangentialBehavior
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.CDCTerm.CDCTerm
        :noindex:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.CDCTermArray.CDCTermArray
        :noindex:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorBehaviorOption.ConnectorBehaviorOption
        :noindex:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorBehaviorOptionArray.ConnectorBehaviorOptionArray
        :noindex:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorDamage.ConnectorDamage
        :noindex:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorDamping.ConnectorDamping
        :noindex:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorElasticity.ConnectorElasticity
        :noindex:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorFailure.ConnectorFailure
        :noindex:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorFriction.ConnectorFriction
        :noindex:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorLock.ConnectorLock
        :noindex:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorOptions.ConnectorOptions
        :noindex:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorPlasticity.ConnectorPlasticity
        :noindex:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorPotential.ConnectorPotential
        :noindex:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorPotentialArray.ConnectorPotentialArray
        :noindex:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.ConnectorStop.ConnectorStop
        :noindex:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.DerivedComponent.DerivedComponent
        :noindex:

        .. autoclasstoc::

    .. autoclass:: abaqus.Connector.TangentialBehavior.TangentialBehavior
        :noindex:

        .. autoclasstoc::
```
